@@ -13,6 +13,7 @@ from pulpcore.plugin.serializers import (
     RepositorySyncURLSerializer,
     SingleArtifactContentSerializer,
     SingleArtifactContentUploadSerializer,
+    SingleContentArtifactField,
     DistributionSerializer,
     RepositoryVersionRelatedField,
     validate_unknown_fields,
@@ -21,6 +22,7 @@ from rest_framework.exceptions import ValidationError
 
 from .models import (
     AnsibleDistribution,
+    GitRemote,
     RoleRemote,
     AnsibleRepository,
     Collection,
@@ -83,6 +85,31 @@ class RoleRemoteSerializer(RemoteSerializer):
         model = RoleRemote
 
 
+class GitRemoteSerializer(RemoteSerializer):
+    """
+    A serializer for Git Collection Remotes.
+    """
+
+    metadata_only = serializers.BooleanField(
+        help_text=_(
+            "If True, only metadata about the content will be stored in Pulp. Clients will "
+            "retrieve content from the remote URL."
+        ),
+        required=False,
+    )
+    git_ref = serializers.CharField(
+        help_text=_("A git ref. e.g.: branch, tag, or commit sha."),
+        required=False,
+    )
+
+    class Meta:
+        model = GitRemote
+        fields = tuple(set(RemoteSerializer.Meta.fields) - {"policy"}) + (
+            "metadata_only",
+            "git_ref",
+        )
+
+
 class AnsibleRepositorySerializer(RepositorySerializer):
     """
     Serializer for Ansible Repositories.
@@ -136,7 +163,6 @@ class CollectionRemoteSerializer(RemoteSerializer):
         allow_null=True,
         required=False,
         max_length=2000,
-        write_only=True,
     )
 
     sync_dependencies = serializers.BooleanField(
@@ -360,6 +386,11 @@ class CollectionVersionSerializer(SingleArtifactContentSerializer, ContentChecks
     A serializer for CollectionVersion Content.
     """
 
+    artifact = SingleContentArtifactField(
+        help_text=_("Artifact file representing the physical content"),
+        required=False,
+    )
+
     id = serializers.UUIDField(source="pk", help_text="A collection identifier.")
 
     authors = serializers.ListField(
